@@ -1,10 +1,12 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Chrome::ExtraPrompt; # git description: v0.006-20-g63414b8
+package Dist::Zilla::Plugin::Chrome::ExtraPrompt; # git description: v0.007-5-ge432ca1
 # ABSTRACT: Perform arbitrary commands when Dist::Zilla prompts you
 # KEYWORDS: prompt execute command external
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
-our $VERSION = '0.007';
+
+our $VERSION = '0.008';
+
 use Moose;
 with 'Dist::Zilla::Role::Plugin';
 use namespace::autoclean;
@@ -50,10 +52,12 @@ around register_component => sub
 __PACKAGE__->meta->make_immutable;
 
 
-package Dist::Zilla::Role::Chrome::ExtraPrompt; # git description: v0.006-20-g63414b8
-our $VERSION = '0.007';
+package Dist::Zilla::Role::Chrome::ExtraPrompt; # git description: v0.007-5-ge432ca1
+
+our $VERSION = '0.008';
+
 use Moose::Role;
-use IPC::Open2;
+use IPC::Open3;
 use File::Spec;
 use POSIX ':sys_wait_h';
 use namespace::autoclean;
@@ -63,6 +67,7 @@ has command => (
     # no point in saying 'required => 1' - the object is already instantiated
     # by the time we apply our role to it
 );
+
 has repeat_prompt => (
     is => 'rw', isa => 'Bool',
 );
@@ -79,17 +84,24 @@ around [qw(prompt_str prompt_yn)] => sub {
 
     open(my $in, '<', File::Spec->devnull);
     open(my $out, '>', File::Spec->devnull);
+    my $err = IO::Handle->new;
 
     my $command = $self->command;
     $command .= ' ' . '"' . $_[0] . '"' if $self->repeat_prompt;
 
-    my $pid = open2($out, $in, $command);
+    my $pid = open3($in, $out, $err, $command);
 
     # wait for the user to respond
     my $input = $self->$orig(@_);
 
     # check what happened to the command
     my $done = waitpid($pid, WNOHANG);
+
+    foreach my $warning (<$err>)
+    {
+        chomp $warning;
+        warn "[Chrome::ExtraPrompt] $warning\n";
+    }
     my $exit_status = $? >> 8;
     warn "[Chrome::ExtraPrompt] process exited with status $exit_status\n" if $done and $exit_status;
 
@@ -97,6 +109,7 @@ around [qw(prompt_str prompt_yn)] => sub {
 
     return $input;
 };
+
 1;
 
 __END__
@@ -111,7 +124,7 @@ Dist::Zilla::Plugin::Chrome::ExtraPrompt - Perform arbitrary commands when Dist:
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
